# piClusterNetworking
Raspberry pi cluster custom server/client library for distributed computing and code testing. This package can be imported to create a custom client/server for any program to send/receive/compute data across any number of clustered raspberry pis.
